""" This is the defautl context file. It replaces the Context class
    to the platform specific one.
"""
import platform


def get_context():
    system = platform.system()
    if system == "Windows":
        from agent.windows._win32context import Context
    elif system == "Linux":
        from agent.linux._linuxcontext import Context
    elif system == "FreeBSD":
        from agent.freebsd._freebsdcontext import Context
    else:
        raise NotImplementedError("Platform %s is not supported.", system)
    return Context


class BaseContext(object):
    @staticmethod
    def change_password(password):
        pass

    @staticmethod
    def restart_networking():
        pass

    @staticmethod
    def change_ip(interfaces, dns):
        pass

    @staticmethod
    def set_time(time):
        pass

    @staticmethod
    def set_hostname(hostname):
        pass

    @staticmethod
    def mount_store(host, username, password):
        pass

    @staticmethod
    def get_keys():
        pass

    @staticmethod
    def add_keys(keys):
        pass

    @staticmethod
    def del_keys(keys):
        pass

    @staticmethod
    def cleanup():
        pass

    @staticmethod
    def start_access_server():
        pass

    @staticmethod
    def append(data, filename, chunk_number, uuid):
        pass

    @staticmethod
    def update(filename, executable, checksum, uuid):
        pass

    @staticmethod
    def ipaddresses():
        pass

    @staticmethod
    def get_agent_version():
        try:
            with open('version.txt') as f:
                return f.readline()
        except IOError:
            return None

    @staticmethod
    def send_expiration(url):
        from agent import notify
        notify.notify(url)

    @staticmethod
    def get_serial():
        raise NotImplementedError()
